**Standalone installation of this package is not supported.** Please install the [dvp](https://pypi.org/project/dvp/) package which will install this package.

# Disclaimer

The software is provided “as-is” without any warranties of any kind. To the maximum extent permitted by applicable law, Delphix Corp. and its affiliates disclaim any liability, implied warranties, including, without limitation, any implied warranties of merchantability, fitness for a particular purpose and non-infringement of intellectual property rights.